The estimates of the spline coefficients for the A component based on the posterior mean from the MCMC method.
beta_c_mc
The estimates of the spline coefficients for the C component based on the posterior mean from the MCMC method.
beta_e_mc
The estimates of the spline coefficients for the E component based on the posterior mean from the MCMC method.
cov_mc
The posterior covariance matrix of the estimates of the spline coefficients.
knots_a
A vector of the knot positions for the A component.
knots_c
A vector of the knot positions for the C component.
knots_e
A vector of the knot positions for the E component.
Arguments
acetp
An object from the 'AtCtEtp' function.
iter_num
The number of the iterations in the MCMC procedure.
sd
The standard error of the normal proposal distribution in the MCMC algorithm. The default value is 0.1.
burnin
The number of burn-in, which must be smaller than the number of iteration.
Author
Liang He
References
He, L., Sillanpää, M.J., Silventoinen, K., Kaprio, J. and Pitkäniemi, J., 2016. Estimating Modifying Effect of Age on Genetic and Environmental Variance Components in Twin Models. Genetics, 202(4), pp.1313-1328.